@@ -19,18 +19,11 @@ class LongestCommonSequence(Similarity):
         return tags
 
     def similarity(self, page1, page2):
-        try:
-            document_1 = lxml.html.parse(StringIO(page1))
-            document_2 = lxml.html.parse(StringIO(page2))
-        except Exception as e:
-            return 0
-
+        document_1 = lxml.html.parse(StringIO(page1))
+        document_2 = lxml.html.parse(StringIO(page2))
         tags1 = self.get_tags(document_1)
         tags2 = self.get_tags(document_2)
-        diff = difflib.SequenceMatcher()
-        diff.set_seq1(tags1)
-        diff.set_seq2(tags2)
-
+        diff = difflib.SequenceMatcher(a=tags1, b=tags2)
         return diff.ratio()
 
 
@@ -39,8 +32,3 @@ class LongestCommonSequenceOptimized(LongestCommonSequence):
     def get_tags(self, doc):
         json = html_to_json_improved(doc.find('body'))
         return json_to_array(json, "tag", "children")
-
-    # def get_classes(self, html):
-    #     document = lxml.html.parse(StringIO(html))
-    #     json = html_to_json_improved(document.find('body'))
-    #     return json_to_array(json, "classes", "children")
